==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfMetafileLayoutFormat.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMetafileLayoutFormat(PdfTextLayout):
    """
    Represents the layout format for a PDF metafile.
    """

    @property
    def SplitTextLines(self) -> bool:
        """
        Gets a value indicating whether to split text lines.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitTextLines.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitTextLines.restype = c_bool
        ret = GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitTextLines(self.Ptr)
        return ret

    @SplitTextLines.setter
    def SplitTextLines(self, value: bool):
        """
        Sets a value indicating whether to split text lines.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitTextLines.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitTextLines(self.Ptr, value)

    @property
    def SplitImages(self) -> bool:
        """
        Gets a value indicating whether to split images.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitImages.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitImages.restype = c_bool
        ret = GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitImages(self.Ptr)
        return ret

    @SplitImages.setter
    def SplitImages(self, value: bool):
        """
        Sets a value indicating whether to split images.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitImages.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitImages(self.Ptr, value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfMetafileLayoutFormat.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMetafileLayoutFormat(PdfTextLayout):
    """
    Represents the layout format for a PDF metafile.
    """

    @property
    def SplitTextLines(self) -> bool:
        """
        Gets a value indicating whether to split text lines.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitTextLines.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitTextLines.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitTextLines,self.Ptr)
        return ret

    @SplitTextLines.setter
    def SplitTextLines(self, value: bool):
        """
        Sets a value indicating whether to split text lines.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitTextLines.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitTextLines,self.Ptr, value)

    @property
    def SplitImages(self) -> bool:
        """
        Gets a value indicating whether to split images.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitImages.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitImages.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfMetafileLayoutFormat_get_SplitImages,self.Ptr)
        return ret

    @SplitImages.setter
    def SplitImages(self, value: bool):
        """
        Sets a value indicating whether to split images.
        """
        GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitImages.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfMetafileLayoutFormat_set_SplitImages,self.Ptr, value)
